@@ -104,9 +104,7 @@ class RPSCell(Cell):
 
         """
 
-        neighbors = self.get_neighbors()
-
-        if len(neighbors) < 1:
+        if len(self.neighbors) < 1:
             print("Warning: Can not update RPSCell with 0 neighbors")
             return
 
@@ -120,11 +118,11 @@ class RPSCell(Cell):
 
             distances = self.get_neighbor_distances()
             inv_dist = [1.0/(d + pow(1.02,-10000)) for d in distances]
-            competitor = roulette_select(items=neighbors, fitnesses=inv_dist, n=1)[0]
+            competitor = roulette_select(items=self.neighbors, fitnesses=inv_dist, n=1)[0]
         else:
             # Pick a random neighbor to compete with.  If that neighbor wins, it
             # gets the current cell.
-            competitor = random.choice(neighbors)
+            competitor = random.choice(self.neighbors)
 
         if self.type == self.ROCK and competitor.type == self.PAPER:
             self.type = self.PAPER
