@@ -2,5 +2,5 @@
 
 from seeds.utils.geometry import *
 from seeds.utils.numeric import *
-from seeds.utils.selection import *
+from seeds.utils.sampling import *
 from seeds.utils.statistics import *
